<!-- markdownlint-disable -->

<a href="../../oqtant/util/__init__.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `util`








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
